@@ -1,8 +1,8 @@
-from ._invariance import *
-from ._plotting import *
-from ._run import *
+from .invariance import *
+from .plotting import *
+from .run import *
 
-__version__ = '0.1.4'
+__version__ = '0.1.7'
 __author__ = 'Arthur Pellegrino, Heike Stein'
 
 __all__ = ['invariance', 'decompose', 'grid_search', 'block_mask', 'plot']
